@@ -1,4 +1,4 @@
-"""Plot functions for CoolPandas."""
+"""Barplot module."""
 import pandas as pd
 import plotly.express as px
 import plotly.graph_objects as go
@@ -18,8 +18,8 @@ def barplot(
 
     Args:
         data_frame (pd.DataFrame): DataFrame to plot.
-        x (str): Column to use as x axis.
-        y (str): Column to use as y axis.
+        x_axis (str): Column to use as x axis.
+        y_axis (str): Column to use as y axis.
         title (str): Title of the plot.
         subtitle (str, optional): Subtitle of the plot. Defaults to None.
         **kwargs: Keyword arguments to pass to plotly.express.bar.
@@ -37,6 +37,5 @@ def barplot(
         height=400,
         **kwargs,
     )
-    fig.update_xaxes(tickangle=270)
     fig.update_traces(width=0.5)
     return fig
